using System;
using System.Drawing;
using System.IO;

using MindFusion.Diagramming;


public partial class _Default : System.Web.UI.Page
{
	protected void Page_Load(object sender, EventArgs e)
	{
		if (!IsPostBack)
		{
			Diagram diagram = diagramView.Diagram;
			diagram.SelectAfterCreate = false;
			diagram.ShowGrid = true;
			diagram.ShapeHandlesStyle = HandlesStyle.HatchHandles3;

			// Create a sample diagram
			var start = diagram.Factory.CreateShapeNode(60, 8, 32, 16);
			start.Shape = Shapes.Terminator;
			start.Text = "Start";

			var choice = diagram.Factory.CreateShapeNode(60, 36, 32, 16);
			choice.Shape = Shapes.Decision;
			choice.Text = "Choice";

			var input = diagram.Factory.CreateShapeNode(108, 36, 32, 16);
			input.Shape = Shapes.Save;
			input.Text = "Data input";

			var user = diagram.Factory.CreateShapeNode(136, 36, 16, 16);
			user.Shape = Shapes.Actor;

			var process = diagram.Factory.CreateShapeNode(60, 64, 32, 16);
			process.Shape = Shapes.Procedure;
			process.Text = "Predefined process/routing";

			var document1 = diagram.Factory.CreateShapeNode(8, 64, 16, 16);
			document1.Shape = Shapes.Document;
			document1.Text = "Document";

			var document2 = diagram.Factory.CreateShapeNode(32, 64, 16, 16);
			document2.Shape = Shapes.Document;
			document2.Text = "Document";

			var multiDocument = diagram.Factory.CreateShapeNode(8, 92, 16, 16);
			multiDocument.Shape = Shapes.MultiDocument;
			multiDocument.Text = "Multiple documents";

			var database = diagram.Factory.CreateShapeNode(32, 92, 16, 16);
			database.Shape = Shapes.Database;
			database.Text = "Database";

			var procedure = diagram.Factory.CreateShapeNode(60, 92, 32, 16);
			procedure.Text = "Alternative procedure";

			var delay = diagram.Factory.CreateShapeNode(108, 92, 32, 16);
			delay.Shape = Shapes.Delay;
			delay.Text = "Delay";

			var end = diagram.Factory.CreateShapeNode(60, 120, 32, 16);
			end.Shape = Shapes.Terminator;
			end.Text = "End";

			diagram.Factory.CreateDiagramLink(start, choice);
			diagram.Factory.CreateDiagramLink(choice, process);
			diagram.Factory.CreateDiagramLink(choice, input);
			diagram.Factory.CreateDiagramLink(choice, 3, document1, 0);
			diagram.Factory.CreateDiagramLink(choice, 3, document2, 0);
			diagram.Factory.CreateDiagramLink(document1, multiDocument);
			diagram.Factory.CreateDiagramLink(document2, database);
			diagram.Factory.CreateDiagramLink(process, procedure);
			diagram.Factory.CreateDiagramLink(procedure, delay);
			diagram.Factory.CreateDiagramLink(procedure, end);
		}
	}

	protected override void OnPreRender(EventArgs e)
	{
		base.OnPreRender(e);

		// display the files available for loading
		listFileNames.Items.Clear();
		string localDir = MapPath(@"Files\");
		DirectoryInfo dir = new DirectoryInfo(localDir);
		foreach (FileInfo fileInfo in dir.GetFiles())
			listFileNames.Items.Add(fileInfo.Name);
	}

	protected void btnSave_Click(object sender, EventArgs e)
	{
		if (!String.IsNullOrEmpty(tbFileName.Text))
		{
			string localDir = MapPath(@"Files\");
			diagramView.Diagram.SaveToFile(localDir + tbFileName.Text);
		}
	}

	protected void btnLoad_Click(object sender, EventArgs e)
	{
		if (!String.IsNullOrEmpty(listFileNames.SelectedValue))
		{
			string localDir = MapPath(@"Files\");
			diagramView.Diagram.LoadFromFile(localDir + listFileNames.SelectedValue);
		}
	}
}